"use strict";
var _a, _b, _c;
Object.defineProperty(exports, "__esModule", { value: true });
exports.useConnectors = exports.walletConnectHooks = exports.walletConnect = exports.injectedHooks = exports.injected = exports.networkHooks = exports.network = exports.getConnectorForWallet = exports.getWalletForConnector = exports.SELECTABLE_WALLETS = exports.Wallet = void 0;
const core_1 = require("@web3-react/core");
const metamask_1 = require("@web3-react/metamask");
const network_1 = require("@web3-react/network");
const walletconnect_1 = require("@web3-react/walletconnect");
const react_1 = require("react");
const infura_1 = require("../constants/infura");
var Wallet;
(function (Wallet) {
    Wallet["INJECTED"] = "INJECTED";
    Wallet["COINBASE_WALLET"] = "COINBASE_WALLET";
    Wallet["WALLET_CONNECT"] = "WALLET_CONNECT";
    Wallet["FORTMATIC"] = "FORTMATIC";
    Wallet["NETWORK"] = "NETWORK";
    Wallet["GNOSIS_SAFE"] = "GNOSIS_SAFE";
})(Wallet = exports.Wallet || (exports.Wallet = {}));
exports.SELECTABLE_WALLETS = [Wallet.COINBASE_WALLET, Wallet.WALLET_CONNECT, Wallet.INJECTED];
function onError(error) {
    console.debug(`web3-react error: ${error}`);
}
function getWalletForConnector(connector) {
    switch (connector) {
        case exports.injected:
            return Wallet.INJECTED;
        case exports.walletConnect:
            return Wallet.WALLET_CONNECT;
        case exports.network:
            return Wallet.NETWORK;
        default:
            throw Error('unsupported connector');
    }
}
exports.getWalletForConnector = getWalletForConnector;
function getConnectorForWallet(wallet) {
    switch (wallet) {
        case Wallet.INJECTED:
            return exports.injected;
        case Wallet.WALLET_CONNECT:
            return exports.walletConnect;
        case Wallet.NETWORK:
            return exports.network;
        default:
            throw Error('unsupported wallet');
    }
}
exports.getConnectorForWallet = getConnectorForWallet;
function getHooksForWallet(wallet) {
    switch (wallet) {
        case Wallet.INJECTED:
            return exports.injectedHooks;
        case Wallet.WALLET_CONNECT:
            return exports.walletConnectHooks;
        case Wallet.NETWORK:
            return exports.networkHooks;
        default:
            throw Error('unsupported wallet');
    }
}
_a = (0, core_1.initializeConnector)((actions) => new network_1.Network({ actions, urlMap: infura_1.INFURA_NETWORK_URLS, defaultChainId: 1 })), exports.network = _a[0], exports.networkHooks = _a[1];
_b = (0, core_1.initializeConnector)((actions) => new metamask_1.MetaMask({ actions, onError })), exports.injected = _b[0], exports.injectedHooks = _b[1];
_c = (0, core_1.initializeConnector)((actions) => new walletconnect_1.WalletConnect({
    actions,
    options: {
        rpc: infura_1.INFURA_NETWORK_URLS,
        qrcode: true,
    },
    onError,
})), exports.walletConnect = _c[0], exports.walletConnectHooks = _c[1];
function getConnectorListItemForWallet(wallet) {
    return {
        connector: getConnectorForWallet(wallet),
        hooks: getHooksForWallet(wallet),
    };
}
function useConnectors(selectedWallet) {
    return (0, react_1.useMemo)(() => {
        const connectors = [];
        if (selectedWallet) {
            connectors.push(getConnectorListItemForWallet(selectedWallet));
        }
        connectors.push(...exports.SELECTABLE_WALLETS.filter((wallet) => wallet !== selectedWallet).map(getConnectorListItemForWallet));
        connectors.push({ connector: exports.network, hooks: exports.networkHooks });
        const web3ReactConnectors = connectors.map(({ connector, hooks }) => [
            connector,
            hooks,
        ]);
        return web3ReactConnectors;
    }, [selectedWallet]);
}
exports.useConnectors = useConnectors;
//# sourceMappingURL=useConnectors.js.map