import { Web3ReactProvider } from '@web3-react/core';
import { injected, network } from '../hooks/useConnectors';
import React, { useEffect } from 'react';
import { useLocalStorage } from 'usehooks-ts';
import { useConnectors, getConnectorForWallet } from '../hooks/useConnectors';
import { isMobile } from '../utils/userAgent';
export const WalletContext = React.createContext({
    setSelectedWallet: () => { },
});
export default function WalletProvider({ children }) {
    const [selectedWallet, setSelectedWallet] = useLocalStorage('selectedWallet', null);
    const connectors = useConnectors(selectedWallet);
    const isMetaMask = !!window.ethereum?.isMetaMask;
    const connect = async (connector) => {
        try {
            if (connector.connectEagerly) {
                await connector.connectEagerly();
            }
            else {
                await connector.activate();
            }
        }
        catch (error) {
            console.debug(`web3-react eager connection error: ${error}`);
        }
    };
    useEffect(() => {
        connect(network);
        if (isMobile && isMetaMask) {
            injected.activate();
        }
        if (selectedWallet) {
            connect(getConnectorForWallet(selectedWallet));
        }
        // The dependency list is empty so this is only run once on mount
        // eslint-disable-line react-hooks/exhaustive-deps
    }, []);
    return (React.createElement(WalletContext.Provider, { value: {
            setSelectedWallet,
        } },
        React.createElement(Web3ReactProvider, { connectors: connectors }, children)));
}
//# sourceMappingURL=WalletProvider.js.map